@@ -314,6 +314,7 @@ class Channel(virtual.Channel):
     _in_poll = False
     _in_listen = False
     _fanout_queues = {}
+    ack_emulation = True
     unacked_key = 'unacked'
     unacked_index_key = 'unacked_index'
     unacked_mutex_key = 'unacked_mutex'
@@ -327,7 +328,8 @@ class Channel(virtual.Channel):
 
     from_transport_options = (
         virtual.Channel.from_transport_options +
-        ('unacked_key',
+        ('ack_emulation',
+         'unacked_key',
          'unacked_index_key',
          'unacked_mutex_key',
          'unacked_mutex_expire',
@@ -342,6 +344,9 @@ class Channel(virtual.Channel):
         super_ = super(Channel, self)
         super_.__init__(*args, **kwargs)
 
+        if not self.ack_emulation:  # disable visibility timeout
+            self.QoS = virtual.QoS
+
         self._queue_cycle = []
         self.Client = self._get_client()
         self.ResponseError = self._get_response_error()
@@ -642,17 +647,6 @@ class Channel(virtual.Channel):
                 super(KombuRedis, self).__init__(*args, **kwargs)
                 self.connection = self.connection_pool.get_connection('_')
 
-            def execute_command(self, *args, **options):
-                conn = self.connection
-                command_name = args[0]
-                try:
-                    conn.send_command(*args)
-                    return self.parse_response(conn, command_name, **options)
-                except redis.ConnectionError:
-                    conn.disconnect()
-                    conn.send_command(*args)
-                    return self.parse_response(conn, command_name, **options)
-
         return KombuRedis
 
     @contextmanager
