@@ -220,7 +220,8 @@ def retry_over_time(fun, catch, args=[], kwargs={}, errback=None,
                 raise
             if callback:
                 callback()
-            tts = errback(exc, interval_range, retries) if errback else None
+            tts = (errback(exc, interval_range, retries) if errback
+                   else next(interval_range))
             if tts:
                 for i in range(int(tts / interval_step)):
                     if callback:
